# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['dynatademand']

package_data = \
{'': ['*'],
 'dynatademand': ['schemas/request/body/*',
                  'schemas/request/path/*',
                  'schemas/request/query/*']}

install_requires = \
['jsonschema==3.2.0', 'requests==2.22.0']

setup_kwargs = {
    'name': 'dynatademand',
    'version': '1.0.3',
    'description': 'A Python client library for the Dynata Demand API',
    'long_description': '# python-demandapi-client\n\n[![PyPI version](https://badge.fury.io/py/dynatademand.svg)](https://pypi.org/project/dynatademand/)\n\n<a href="https://github.com/dynata/python-demandapi-client/actions?query=branch%3Adev"><img alt="GitHub Actions status" src="https://github.com/dynata/python-demandapi-client/workflows/python-tests/badge.svg"></a>\n\nA Python client library for the [Dynata Demand API](https://developers.dynata.com/). There are also [go](https://github.com/researchnow/go-samplifyapi-client) and [.NET](https://github.com/researchnow/dotnet-samplifyapi-client) clients available.\n\n## Setup\n\nYou can install the Demand API client with:\n\n    pip install dynatademand\n\nYou can provide your Demand API credentials in a couple of ways. They can be set in the environment (a sample config is provided in `.env-example`) or you can provide them while creating the client object.\n\n## Example Usage\n\n```python\n# You can optionally provide your credentials here instead of environment variables.\ndemandapi = DemandAPIClient("client_id", "username", "password")\ndemandapi.authenticate()\n\n# Any function requiring one or more IDs should be provided as positional arguments.\ndemandapi.get_project(7)\n\n# Provide query parameters as keyword-arguments.\ndemandapi.get_projects(state="LAUNCHED")\n\n# Functions that send data in a request body accept a python dictionary.\n# Your data will be validated against the schemas provided in the Demand API documentation.\nproject_data = {\n  \'title\': \'My New Survey\',\n  ...\n}\ndemandapi.create_project(project_data)\n```\n\n## Supported API Functions\n\nLinks to the Demand API documentation are included for each function.\n\n### Authentication Functions\n\n[Obtain Access Token](https://developers.dynata.com/demand-api-reference/authentication/authentication/post-token): authenticate()  \n[Refresh Access Token](https://developers.dynata.com/demand-api-reference/authentication/authentication/post-token-refresh): refresh_access_token()  \n[Logout](https://developers.dynata.com/demand-api-reference/authentication/authentication/post-logout): logout()  \n\n### Event Functions\n\n[Get Event](https://developers.dynata.com/demand-api-reference/notifications/events/get-event): get_event(event_id)  \n[Get Events](https://developers.dynata.com/demand-api-reference/notifications/events/get-events): get_events(\\*\\*kwargs)  \n\n### Project Functions\n\n[Buy Project](https://developers.dynata.com/demand-api-reference/core-resources/projects/post-project-buy): buy_project(project_id, buy_data)  \n[Close Project](https://developers.dynata.com/demand-api-reference/core-resources/projects/post-close-project): close_project(project_id)  \n[Create Project](https://developers.dynata.com/demand-api-reference/core-resources/projects/post-projects): create_project(project_data)  \n[Get Project](https://developers.dynata.com/demand-api-reference/core-resources/projects/get-project): get_project(project_id)  \n[Get Projects](https://developers.dynata.com/demand-api-reference/core-resources/projects/get-projects): get_projects(\\*\\*kwargs)  \n[Update Project](https://developers.dynata.com/demand-api-reference/core-resources/projects/post-project): update_project(project_id, update_data)  \n[Get Project Detailed Report](https://developers.dynata.com/demand-api-reference/core-resources/projects/get-project-detailed-report): get_project_detailed_report(project_id)  \n[Get Pricing & Feasibility](https://developers.dynata.com/demand-api-reference/core-resources/pricing-feasibility/get-pricing-feasibility): get_feasibility(project_id)  \n[Get Invoice PDF](https://developers.dynata.com/demand-api-reference/billing_invoicing/invoicing/get-invoices): get_invoice(project_id)  \n\n### Line Item Functions\n\n[Add Line Item](https://developers.dynata.com/demand-api-reference/core-resources/lineitems/post-lineitems): add_line_item(project_id, lineitem_data)  \n[Close Line Item](https://developers.dynata.com/demand-api-reference/core-resources/lineitems/post-lineitem-close): close_line_item(project_id, line_item_id)  \n[Get Line Item](https://developers.dynata.com/demand-api-reference/core-resources/lineitems/get-lineitem): get_line_item(project_id, line_item_id)  \n[Get Line Items](https://developers.dynata.com/demand-api-reference/core-resources/lineitems/get-lineitems): get_line_items(project_id, \\*\\*kwargs)  \n[Launch Line Item](https://developers.dynata.com/demand-api-reference/core-resources/lineitems/post-lineitem-launch): launch_line_item(project_id, line_item_id)  \n[Pause Line Item](https://developers.dynata.com/demand-api-reference/core-resources/lineitems/post-lineitem-pause): pause_line_item(project_id, line_item_id)  \n[Update Line Item](https://developers.dynata.com/demand-api-reference/core-resources/lineitems/post-lineitem): update_line_item(project_id, line_item_id, line_item_data)  \n[Get Line Item Detailed Report](https://developers.dynata.com/demand-api-reference/core-resources/lineitems/get-detailed-line-item): get_line_item_detailed_report(project_id, line_item_id)  \n\n### Misc Functions\n\n[Get Attributes](https://developers.dynata.com/demand-api-reference/data_endpoints/attributes/get-attributes): get_attributes(country_code, language_code, \\*\\*kwargs)  \n[Get Countries](https://developers.dynata.com/demand-api-reference/data_endpoints/countries-languages/get-countries): get_countries(\\*\\*kwargs)  \n[Get Sources](https://developers.dynata.com/demand-api-reference/data_endpoints/supplier-sources/get-sources): get_sources()  \n[Get Survey Topics](https://developers.dynata.com/demand-api-reference/data_endpoints/categories/get-survey-topic): get_survey_topics(\\*\\*kwargs)  \n\n## Contributing\n\nInformation on [contributing](CONTRIBUTING.md).\n\n## Testing\n\nTo run the tests, you will need to install the development requirements to your environment. It\'s recommended to create a virtual environment for your installation to avoid any package conflicts.\n\nYou can check out the code by running:\n\n    git clone https://github.com/dynata/python-demandapi-client.git\n    cd python-demandapi-client\n\nAnd you can create an environment by running:\n\n    # If you\'re using Python 2.7\n    virtualenv venv\n\n    # Or if you\'re using Python 3:\n    python3 -m venv venv\n\n    source venv/bin/activate\n    pip install -r requirements.txt\n\nWhile your virtual environment is activated, you can run `pytest tests` to run the tests.\n',
    'author': 'Ridley Larsen',
    'author_email': 'Ridley.Larsen@dynata.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/dynata/python-demandapi-client',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*',
}


setup(**setup_kwargs)
